/*
 * Copyright (c) 2008-2013 Sonatype, Inc.
 *
 * All rights reserved. Includes the third-party code listed at http://links.sonatype.com/products/nexus/pro/attributions
 * Sonatype and Sonatype Nexus are trademarks of Sonatype, Inc. Apache Maven is a trademark of the Apache Foundation.
 * M2Eclipse is a trademark of the Eclipse Foundation. All other trademarks are the property of their respective owners.
 */
Sonatype.repoServer.m2InformationPanel = function(config) {
  var config = config || {};
  var defaultConfig = {};
  Ext.apply(this, config, defaultConfig);

  this.sp = Sonatype.lib.Permissions;

  this.linkDivId = Ext.id();
  this.linkLabelId = Ext.id();

  this.formPanel = new Ext.form.FormPanel({
        autoScroll : true,
        border : false,
        frame : true,
        collapsible : false,
        collapsed : false,

        items : [{
          xtype : 'panel',
          layout : 'column',
          items : [{
            xtype : 'panel',
            layout : 'form',
            columnWidth : .4,
            labelWidth : 70,
            items : [{
                  xtype : 'textfield',
                  fieldLabel : 'Group',
                  name : 'groupId',
                  anchor : Sonatype.view.FIELD_OFFSET_WITH_SCROLL,
                  allowBlank : true,
                  readOnly : true
                }, {
                  xtype : 'textfield',
                  fieldLabel : 'Artifact',
                  name : 'artifactId',
                  anchor : Sonatype.view.FIELD_OFFSET_WITH_SCROLL,
                  allowBlank : true,
                  readOnly : true
                }, {
                  xtype : 'textfield',
                  fieldLabel : 'Version',
                  name : 'version',
                  anchor : Sonatype.view.FIELD_OFFSET_WITH_SCROLL,
                  allowBlank : true,
                  readOnly : true
                }, {
                  xtype : 'panel',
                  html : '<div class="x-form-item" tabindex="-1">' + '<label id="' + this.linkLabelId + '" class="x-form-item-label" style="width: 70px;"></label>' + '<div id="' + this.linkDivId
                      + '" class="x-form-element" style="padding-left: 75px; padding-top: 3px">' + '</div><div class="x-form-clear-left"/></div>'
                }]
          }, {
            xtype : 'panel',
            layout : 'form',
            columnWidth : .6,
            labelWidth : 30,
            items : [{
                  xtype : 'textarea',
                  fieldLabel : 'XML',
                  name : 'xml',
                  anchor : Sonatype.view.FIELD_OFFSET_WITH_SCROLL,
                  height : 100,
                  allowBlank : true,
                  readOnly : true
                }]
          }]
        }]
      });

  Sonatype.repoServer.m2InformationPanel.superclass.constructor.call(this, {
        title : 'Artifact',
        layout : 'fit',
        region : 'south',
        collapsible : true,
        collapsed : true,
        split : true,
        height : 150,
        minHeight : 100,
        maxHeight : 400,
        frame : false,
        autoScroll : true,

        items : [this.formPanel],

        listeners : {
          expand : {
            fn : function(p) {
              this.formPanel.doLayout();
            },
            scope : this
          }
        }
      });
};

Ext.extend(Sonatype.repoServer.m2InformationPanel, Ext.Panel, {
      formatDownloadLink : function(data) {
        var pomLink = data.pomLink;
        var artifactLink = data.artifactLink;

        var links = [];
        if (pomLink)
        {
          links.push(this.makeDownloadLink(pomLink, 'pom'));
        }
        if (artifactLink)
        {
          links.push(this.makeDownloadLink(artifactLink, 'artifact'));
        }
        return links.join(', ');
      },

      makeDownloadLink : function(url, title) {
        return String.format('<a target="_blank" href="{0}">{1}</a>', url, title);
      },

      showArtifact : function(data, collapse) {
        data.xml = '';
        var empty = data.groupId == null || data.groupId == '';
        if (!empty)
        {
          data.xml = '<dependency>\n' + '  <groupId>' + data.groupId + '</groupId>\n' + '  <artifactId>' + data.artifactId + '</artifactId>\n' + '  <version>' + data.version + '</version>\n'
              + (data.classifier ? ('  <classifier>' + data.classifier + '</classifier>\n') : '') + '</dependency>\n';
        }
        this.formPanel.form.setValues(data);

        if (this.sp.checkPermission('nexus:artifact', this.sp.READ))
        {
          var linkLabel = document.getElementById(this.linkLabelId);
          var linkDiv = document.getElementById(this.linkDivId);
          var linkHtml = this.formatDownloadLink(data);
          if (empty || linkHtml.length == 0)
          {
            linkLabel.innerHTML = '';
          }
          else
          {
            linkLabel.innerHTML = 'Download: ';
            linkDiv.innerHTML = linkHtml;
          }
        }

        if (collapse)
        {
          this.collapse();
        }
        else
        {
          this.expand();
        }
      }
    });
